// data loading
Table table;
int numRows, numCols;
DataRecord[] dataRecords;

// setting min | max
int min_publishOrder = 10000;
int max_publishOrder = 0;
int min_checkout = 10000;
int max_checkout = 0;
int min_year = 2006;
int max_year = 2015;
int min_adoption = 10000;
int max_adoption = 0;
int min_totalCheckout = 10000;
int max_totalCheckout = 0;

PFont gFont2;


// **************************************** //
// **           Data Loading             ** //
// **************************************** //

void loadData(String dataFile){
  table = loadTable(dataFile, "header"); // put data into Processing table from csv
  numRows = table.getRowCount(); // get number of data points
  numCols = table.getColumnCount(); // get number of attributes per data point
  
  // since peasycam is in center, move everything 1/2 distance left
  leftOffset = 1.5*numRows;
  
  // create data points and fill array
  dataRecords = new DataRecord[numRows]; // initialize data points array length
  int counter = 0;
  for (TableRow row : table.rows()) {
    createDataPoint(row, counter);
    counter += 1;
  }
  
  // for each data record, map their values & map initial colors
  for(int i=0; i< dataRecords.length; i++){
    dataRecords[i].mapValues();
    setColorScheme(dataRecords[i]);
  }
}


// **************************************** //
// **           Data Creation            ** //
// **************************************** //

void createDataPoint(TableRow row, int counter){
  int bib           = row.getInt("bib");
  int isbn          = row.getInt("isbn");
  String bookType   = row.getString("bookType");
  String title      = row.getString("title");
  String publishDate  = row.getString("publishDate");
  int publishOrder  = row.getInt("publishOrder");                
  int adoption      = row.getInt("adoption");
  int ageFull       = row.getInt("ageFull");
  int ageCheckouts  = row.getInt("ageCheckouts");
  int n2006         = row.getInt("2006");
  int n2007         = row.getInt("2007");
  int n2008         = row.getInt("2008");
  int n2009         = row.getInt("2009");
  int n2010         = row.getInt("2010");
  int n2011         = row.getInt("2011");
  int n2012         = row.getInt("2012");
  int n2013         = row.getInt("2013");
  int n2014         = row.getInt("2014");
  int n2015         = row.getInt("2015");
  int totalCheckout = row.getInt("totalCheckout");
  
  // create new data point and add to dataPoints array
  dataRecords[counter] = new DataRecord(bib, isbn, bookType, title, publishDate, publishOrder, adoption, ageFull, ageCheckouts, n2006, n2007, n2008, n2009, n2010, n2011, n2012, n2013, n2014, n2015, totalCheckout);
  
  // X min | max
  if(publishOrder < min_publishOrder){min_publishOrder = publishOrder;}
  if(publishOrder > max_publishOrder){max_publishOrder = publishOrder;}
  
  // Y min | max
  int[] temp_YearArray = {n2006, n2007, n2008, n2009, n2010, n2011, n2012, n2013, n2014, n2015};
  temp_YearArray = sort(temp_YearArray);
  int checkoutMin = temp_YearArray[0];
  int checkoutMax = temp_YearArray[temp_YearArray.length - 1];
  if(checkoutMin < min_checkout){min_checkout = checkoutMin;}
  if(checkoutMax > max_checkout){max_checkout = checkoutMax;}
  
  // Adoption min | max
  if(adoption < min_adoption){min_adoption = adoption;}
  if(adoption > max_adoption){max_adoption = adoption;}
  
  // total checkout min | max
  if(totalCheckout < min_totalCheckout){min_totalCheckout = totalCheckout;}
  if(totalCheckout > max_totalCheckout){max_totalCheckout = totalCheckout;}
  
}


void loadColors(){
  gFont2 = createFont("Helvetica", 22);
}