##Content Description
The following results are a continuation from the last step of my project, determining the relationship between media checkout frequency, age, and time. In summary, my project aims to understand the relationship between several quantifications of physical checkout frequency and media age in an evolving age of online content competition.  

Based on previous limitations, the original dataset has been restricted to physical books published since the new library's opening. Variables have been generated by observing the temporal differences in publication date, first checkout, last checkout and total checkout counts. *Please see last submission for further background information*. 
##Data Collection
Thus far, this has been the most time consuming portion of this project. Paired with data from the Seattle Public Library database, I have gathered Amazon book data via API calls. Through customized constructed tools with several machines making calls, I was able to retrieve roughly 118,000 unique ISBN records. This was needed to retrieve `publicationDate` data. Paired with Seattle Public Library data for `minCheckOut` `maxCheckOut` `itemType` `checkOutCount` with the assistance from `bibNumber` and `ISBN` for joining purposes. Ultimately, these five data elements can give us insight into the following questions:
> * Is there a relationship between book adoption rate and checkout frequency?  
> * Does publication date play a role on adoption and/or frequency?
> * Are there any noticeably different trends between book genre types?

##Queries

#####Preliminary
`isbn_query.sql` all unique isbn values & according bib *(used for Amazon API)*
#####Secondary
`count_and_type.sql` retrieves checkout count & item type *(for each bib)*  
`min_max_count.sql` retrieves min & max checkout dates *(for each bib)*


*SQL query processing times include" 768sec, 557sec, and accordingly. Joining has reduced optimal record counts from ~108000 to ~3600 to ~3300 to `~1600 final records`. After several joins, the final dataset has the following columns:*

	bib              | unique identifier
	isbn             | unique identifier
	publishDate      | publish or release date
	minCheckOut      | first recorded checkout
	maxCheckOut      | most recent recorded checkout
	checkOutCount    | number of total checkouts
	itemType         | book subtype
	adoption         | media adoption (minCheckOut - publishDate)
	age              | media 'age' (maxCheckOut - publishDate)
	relativeAge      | media relative 'age' (maxCheckOut - 'oldest' media publishDate)
	fullFrequency    | checkout frequency (checkOutCount / (maxCheckOut - publishDate)) *100
	partialFrequency | partial checkout frequency (checkOutCount / (maxCheckOut - minCheckOut)) *100


####Query Errors
There have been several errors that have reduced the amount of data visualized. This could, in fact, be a positive thing because I am uncertain how processing would have handled upwards of 100000 records. These errors include and may not be limited to: accidental duplication query from Amazon API, improper table join characteristics, accidental type conversion on joins. In addition, as always final data acquisition is  dependent on every step of the process. Original web crawling data had a limited number of ISBN records to search Amazon’s API for and ultimately join back.
##Analysis
Based on initial observations, it appears that checkout frequency, normalized by media age `(checkout count /(last checkout - publication date))` and relative age `(checkout count /(last checkout - first checkout))` has not significantly changed over time. This agrees with my hypothesis that book checkout will not decrease (and may increase) with time, even with the introduction of e-media. To further investigate this, I plan on pulling in more variables, including genre types.  

I am satisfied with this visualization because immediately the colors cooperate, and don't distract from the data's powerful visual distribution. Interactive options including: toggling 'x' values between age and relative age, toggling 'y' values between full and partial frequency, and toggling color between publication date and book type are both easy to transition between and engaging to cycle between. Additionally, animation effects, such as movement of points when toggled, give a clear sense of order and relationships.
##Limitations
As of this writing, the data collection and visualization have been a success. However, due to time constraints and alteration in design foundations, this project will need revisiting. The dataset has several opinionated variables, and further data normalization needs to occur. To do this, I will integrate heavier statistical methods acquired through my parallel Geography 210B assignments. This will include, normalization through ranks, gamma and other distributions. I hope to apply several forms of regression to this dataset, and explore how statistical summaries can be creatively visualized. This element should be applicable to the 3D visualization portion of this course. 
